@@ -1,19 +1,20 @@
-/* Aisleriot - menu.c
- * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+/* AisleRiot - menu.c
+ * Copyright (C) 1998 Jonathan Blandford <jrb@alum.mit.edu>
  *
- * This game is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This game is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ * USA
  */
 
 #include <config.h>
@@ -24,6 +25,8 @@
 #include "dialog.h"
 #include "cscmi.h"
 #include "draw.h"
+static GtkWidget *about = NULL;
+
 
 void restart_game ()
 {
@@ -51,29 +54,52 @@ void redo_callback ()
   gh_eval_str ("(redo)");
   refresh_screen();
 }
+static void
+about_destroy_callback (void)
+{
+	about = NULL;
+}
 
+ 
 void help_about_callback ()
 {
-  GtkWidget *about;
   const gchar *authors[] = {
-	  "Main program:  Jonathan Blandford (jrb@mit.edu)",
-	  "                      Felix Bellaby (felix@pooh.u-net.com)",
-	  "Card Games:    Jonathan Blandford (jrb@mit.edu)",
-	  "                      Changwoo Ryu (cwryu@adam.kaist.ac.kr)",
-	  "                      Rosanna Yuen (rwsy@mit.edu)",
-          NULL
-          };
+	  N_("Main program:  Jonathan Blandford (jrb@alum.mit.edu)"),
+	  N_("                      Felix Bellaby (felix@pooh.u-net.com)"),
+	  N_("                      Rosanna Yuen (rwsy@mit.edu)"),
+	  N_("Card Games:    Jonathan Blandford (jrb@alum.mit.edu)"),
+	  N_("                      W. Borgert (debacle@debian.org)"),
+	  N_("                      Robert Brady (rwb197@ecs.soton.ac.uk)"),
+	  N_("                      Nick Lamb (njl195@zepler.org.uk)"),
+	  N_("                      Changwoo Ryu (cwryu@adam.kaist.ac.kr)"),
+	  N_("                      Rosanna Yuen (rwsy@mit.edu)"),
+	  NULL
+  };
 
-  about = gnome_about_new ( _("GNOME Solitaire"), VERSION,
-        		/* copyright notice */
-                        "(C) 1998 Jonathan Blandford (jrb@MIT.EDU)",
-                        (const char **)authors,
-                        /* another comments */
-                        _("The GNOME Generic Solitaire provides a rule-based "
-			  "solitaire engine that allows many different games to be played"),
-                        NULL);
+#ifdef ENABLE_NLS
+  {
+	int i=0;
+	while (authors[i] != NULL) { authors[i]=_(authors[i]); i++; }
+  }
+#endif
+
+  if (about) {
+    gdk_window_raise (about->window);
+    return;
+  }
+  about = gnome_about_new ( _("AisleRiot"), VERSION,
+			    /* copyright notice */
+			    _("(C) 1998 Jonathan Blandford (jrb@alum.mit.edu)"),
+			    (const char **)authors,
+			    /* another comments */
+			    _("AisleRiot provides a rule-based "
+			      "solitaire card engine that allows many different games to be played"),
+			    NULL);
+  gtk_signal_connect (GTK_OBJECT (about),
+		      "destroy",
+		      (GtkSignalFunc) about_destroy_callback,
+		      NULL);
   gtk_widget_show (about);
-
   return;
 }
 
@@ -87,13 +113,13 @@ GnomeUIInfo file_menu[] = {
 
 GnomeUIInfo settings_menu[] = {
 
-  
+#if 0
   GNOMEUIINFO_ITEM_STOCK(N_("Game _options..."),
 			 N_("Modify the options for this game"),
 			 show_rules_options_dialog, GNOME_STOCK_MENU_PREF),
 
   GNOMEUIINFO_SEPARATOR,
-
+#endif
   GNOMEUIINFO_MENU_PREFERENCES_ITEM(show_preferences_dialog, NULL),
 
   GNOMEUIINFO_END
@@ -137,13 +163,13 @@ GnomeUIInfo game_menu[] = {
       show_property_dialog, GNOME_STOCK_MENU_PREF), */
 
   GNOMEUIINFO_SEPARATOR,
-
+#if 0
   GNOMEUIINFO_MENU_SCORES_ITEM(show_global_stats_dialog, NULL),
   /*  GNOMEUIINFO_ITEM_STOCK(N_("S_tatistics..."), NULL, 
       show_global_stats_dialog, GNOME_STOCK_MENU_BOOK_BLUE), */
 
   GNOMEUIINFO_SEPARATOR,
-
+#endif
   GNOMEUIINFO_MENU_EXIT_ITEM(quit_app, NULL),
 
   GNOMEUIINFO_END
@@ -163,29 +189,29 @@ GnomeUIInfo top_menu[] = {
 
 GnomeUIInfo toolbar[] =
 {
-  GNOMEUIINFO_ITEM_STOCK(N_("New"), N_("Deal a new game."),
+  GNOMEUIINFO_ITEM_STOCK(N_("New"), N_("Deal a new game"),
 			 random_seed, GNOME_STOCK_PIXMAP_NEW),
 
-  GNOMEUIINFO_ITEM_STOCK(N_("Restart"), N_("Start this game over."),
+  GNOMEUIINFO_ITEM_STOCK(N_("Restart"), N_("Start this game over"),
 			 restart_game, GNOME_STOCK_PIXMAP_REFRESH),
 
-  GNOMEUIINFO_ITEM_STOCK(N_("Select"), N_("Select a new game."),
+  GNOMEUIINFO_ITEM_STOCK(N_("Select"), N_("Select a new game"),
 			 show_select_game_dialog, GNOME_STOCK_PIXMAP_OPEN),
 
   GNOMEUIINFO_SEPARATOR,
 
-  GNOMEUIINFO_ITEM_STOCK(N_("Hint"), N_("Suggest a move."),
+  GNOMEUIINFO_ITEM_STOCK(N_("Hint"), N_("Suggest a move"),
 			 show_hint_dialog, GNOME_STOCK_PIXMAP_JUMP_TO),
 
-  GNOMEUIINFO_ITEM_STOCK(N_("Undo"), N_("Undo the last move."),
+  GNOMEUIINFO_ITEM_STOCK(N_("Undo"), N_("Undo the last move"),
 			 undo_callback, GNOME_STOCK_PIXMAP_UNDO),
 
-  GNOMEUIINFO_ITEM_STOCK(N_("Redo"), N_("Redo the last move."),
+  GNOMEUIINFO_ITEM_STOCK(N_("Redo"), N_("Redo the last move"),
 			 redo_callback, GNOME_STOCK_PIXMAP_REDO),
 
   GNOMEUIINFO_SEPARATOR,
 
-  GNOMEUIINFO_ITEM_STOCK(N_("Exit"), N_("Quit Aisleriot."),
+  GNOMEUIINFO_ITEM_STOCK(N_("Exit"), N_("Quit Aisleriot"),
 			 quit_app, GNOME_STOCK_PIXMAP_EXIT),
   GNOMEUIINFO_END
 };
