@@ -115,10 +115,10 @@ guint pos
   }
 
   if(properties_safe_moves()){
-    sprintf(nbuf, "'%s' with safe moves", 
-	    game_config_name(current_game_config()));
+    sprintf(nbuf, _("'%s' with safe moves"), 
+	    _(game_config_name(current_game_config())));
   } else {
-    sprintf(nbuf, "'%s'", game_config_name(current_game_config()));
+    sprintf(nbuf, "'%s'", _(game_config_name(current_game_config())));
   }
 
   gnome_scores_display(nbuf, GAME_NAME, sbuf, pos);
