@@ -210,6 +210,8 @@ char *argv[]
   app = gnome_app_new(GAME_NAME, _("Gnome Robots II") );
   gtk_window_set_policy(GTK_WINDOW(app), FALSE, FALSE, TRUE);
 
+  gtk_signal_connect(GTK_OBJECT(app), "delete_event",
+		     GTK_SIGNAL_FUNC(exit_cb), NULL);
 
   stbar = gnobots_statusbar_new();
   gnome_app_set_statusbar(GNOME_APP(app), stbar);
