@@ -34,19 +34,6 @@
 #include "yahtzee.h"
 #include "gyahtzee.h"
 
-#define GY_NEW 0  /* Just so I can play with stuff w/o breaking the dist */
-
-#if GY_NEW
-guint  gtk_signal_new			  (const gchar	       *name,
-					   GtkSignalRunType	signal_flags,
-					   GtkType		object_type,
-					   guint		function_offset,
-					   GtkSignalMarshaller	marshaller,
-					   GtkType		return_val,
-					   guint		nparams,
-					   ...);
-#endif
-
 void
 update_score_cell(GtkCList * clist, gint row, gint col, int val)
 {
@@ -57,38 +44,8 @@ update_score_cell(GtkCList * clist, gint row, gint col, int val)
         gtk_clist_set_text(clist,row,col,buf);
 }
 
-#if 0
-/* This version doesn't do a thing */
-void
-ShowoffPlayer(GtkCList * clist, int player, int so)
-{
-        gint column;
-        GtkButton *button;
-        
-        g_return_if_fail (clist != NULL);
-        
-        column = player + 1;
-        
-        if (column < 0 || column >= clist->columns)
-                return;
-        
-        button = GTK_BUTTON(clist->column[column].button);
 
-        if (so)
-                gtk_clist_column_title_active (clist, column);
-        else
-                gtk_clist_column_title_passive (clist, column);
-
-        gtk_widget_draw(GTK_WIDGET(button),NULL);
-}
-#elif 0
-/* This one really does nothing */
-void
-ShowoffPlayer(GtkCList * clist, int player, int so)
-{
-}
-#else
-/* This version is full of cheats.  Goes into gtk code, access 
+/* This is full of cheats.  Goes into gtk code, access 
  * structures that would probably be private under C++.  Works now 
  * because clist*title_pass/active() doesn't do a redraw, may have to be
  * modified later. */
@@ -107,27 +64,17 @@ ShowoffPlayer(GtkCList * clist, int player, int so)
         
         button = GTK_BUTTON(clist->column[column].button);
 
-        gtk_clist_column_title_active(clist, column);
-
         if (so) {
                 button->button_down = TRUE;
-#if 1
-                /* Press it */
                 gtk_widget_set_state (GTK_WIDGET (button), GTK_STATE_ACTIVE);
-#else
-                /* Lighten it */
-                gtk_widget_set_state (GTK_WIDGET (button), GTK_STATE_PRELIGHT);
-#endif
         } else {
                 button->button_down = FALSE;
                 gtk_widget_set_state (GTK_WIDGET (button), GTK_STATE_NORMAL);
         }
   
         gtk_widget_draw(GTK_WIDGET(button),NULL);
-        gtk_clist_column_title_passive(clist, column);
 
 }
-#endif
 
 static gint LastScoredRow = -1;
 
@@ -161,11 +108,6 @@ select_row(GtkCList * clist, gint row, gint col, GdkEventButton * event)
 	case (R_BLANK1):
 	case (R_GTOTAL):
 	case (R_LTOTAL):
-#if GY_NEW
-                g_print("Selection should have been blocked!!!\n");
-                gtk_signal_emit_stop_by_name(GTK_OBJECT(clist), "select_row");
-                return TRUE;
-#endif
                 break;
 
 	default:
@@ -183,11 +125,6 @@ select_row(GtkCList * clist, gint row, gint col, GdkEventButton * event)
                                 NextPlayer();
                                 return TRUE;
                         }
-#if GY_NEW
-                } else {
-                        /* Don't want to unselect row? */
-                        return FALSE;
-#endif
                 }
 	}
         
@@ -196,90 +133,21 @@ select_row(GtkCList * clist, gint row, gint col, GdkEventButton * event)
         return FALSE;
 }
 
-#if GY_NEW
 static gint
-select_row2(GtkCList *clist, gint row, gint col, GdkEventButton *event)
+RenamePlayerCallback(GtkWidget *widget, GdkEventButton *event, gpointer func_data)
 {
-#if GY_NEW
-        int field = row;
-
-	if (!event) 
-                return FALSE;
-
-        LastScoredRow = -1;
-
-	switch (row) {
-
-	case (R_UTOTAL):	/* Can't select total/blank rows */
-	case (R_BONUS):
-	case (R_BLANK1):
-	case (R_GTOTAL):
-	case (R_LTOTAL):
-                break;
-
-	default:
-                /* Adjust for Upper Total / Bonus entries */
-                if (field >= NUM_UPPER)
-                        field -= 3;
-
-                if ( (field < NUM_FIELDS) && 
-		     (!players[CurrentPlayer].finished)  ) {
-                        if (play_score(CurrentPlayer,field)==SLOT_USED) {
-                                say(_("Already used! " 
-				      "Where do you want to put that?"));
-                        } else {
-			        LastScoredRow = row;
-                                NextPlayer();
-                                return FALSE;
-                        }
-                }
-	}
-
-        g_print("After: Selection should have been blocked!!!\n");
-        gtk_signal_emit_stop_by_name(GTK_OBJECT(clist), "select_row");
-        return TRUE;
-#else
-	return FALSE;
-#endif
-}
-#endif /* GY_NEW */
-
-
-/* This won't work.  Can't tell if we're being called to deselect 
-   selected row  prior to selection of new row or just to deselect 
-   current row and leave nothing selected */
-/* There's no real reason to have this function since I've taken care of the
- * problem, but I'll leave it here anyways because ... I dunno, just because.
- * -- pschwan@cmu.edu */
-#if GY_NEW
-static gint
-unselect_row(GtkCList *clist, gint row, gint col, GdkEventButton *event)
-{
-#if GY_NEW
-	if (!event) 
-                return FALSE;
-
-        /* Multiple humans need to sometimes select score rows that are
-         * highlighted */
-        if (row==LastScoredRow) {
-                LastScoredRow = -1;
-                select_row(clist, row, col, event);
-        }
-
+        if ((event->type==GDK_BUTTON_RELEASE)&&(event->button==3))
+                GRenamePlayer((gint)func_data-1);
+        
         return FALSE;
-#else
-        return FALSE;
-#endif
 }
-#endif /* GY_NEW */
-
 
 GtkWidget * create_clist(void)
 {
 	GtkStyle *style;
 	GdkGCValues vals;
         
-	GtkWidget *clist;
+	GtkCList *clist;
 	char *titles[MAX_NUMBER_OF_PLAYERS+2];
         
 	int i;
@@ -287,44 +155,45 @@ GtkWidget * create_clist(void)
         titles[MAX_NUMBER_OF_PLAYERS+1] = titles[0] = "";
         for (i=0; i<MAX_NUMBER_OF_PLAYERS; i++)
                 titles[i+1] = players[i].name;
-	clist = gtk_clist_new_with_titles(8,titles);
-	gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_SINGLE);
+	clist = GTK_CLIST(gtk_clist_new_with_titles(8,titles));
+	gtk_clist_set_selection_mode(clist, GTK_SELECTION_SINGLE);
         
-	gtk_clist_set_column_justification(GTK_CLIST(clist), 0,
+	gtk_clist_set_column_justification(clist, 0,
 					   GTK_JUSTIFY_LEFT);
-	for (i=1; i<8; i++)
-                gtk_clist_set_column_justification(GTK_CLIST(clist), i,
+	for (i=1; i<8; i++) {
+                gtk_clist_set_column_justification(clist, i,
                                                    GTK_JUSTIFY_RIGHT);
-	style = gtk_widget_get_style(clist);
+		gtk_signal_connect(GTK_OBJECT(clist->column[i].button),
+				   "button_release_event",
+				   GTK_SIGNAL_FUNC(RenamePlayerCallback),
+				   (gpointer)i);	
+        }
+	style = gtk_widget_get_style(GTK_WIDGET(clist));
 	g_return_val_if_fail(style != NULL, NULL);
 	if (!style->fg_gc[0]) {
-                gtk_clist_set_column_width(GTK_CLIST(clist), 0, 140);
+                gtk_clist_set_column_width(clist, 0, 140);
                 for (i=1; i<7; i++)
-                        gtk_clist_set_column_width(GTK_CLIST(clist), i, 95);
+                        gtk_clist_set_column_width(clist, i, 95);
 	} else {
                 /* !!!!!!!!! BROKEN !!!!!!!! */
                 gdk_gc_get_values(style->fg_gc[0], &vals);
-                gtk_clist_set_column_width(GTK_CLIST(clist), 0, 
+                gtk_clist_set_column_width(clist, 0, 
                         gdk_string_width(vals.font,"XCLarge Straight [40]XC"));
                 for (i=1; i<7; i++)
-                        gtk_clist_set_column_width(GTK_CLIST(clist), i, 
+                        gtk_clist_set_column_width(clist, i, 
                                gdk_string_width(vals.font, "SomeLongName"));
 	}
 /*	FIXME 
  * clists no longer get a scrolled window to play in the app has to provide
  * it. 
-	gtk_clist_set_policy(GTK_CLIST(clist),
+	gtk_clist_set_policy(clist,
                              GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  */
 	gtk_signal_connect(GTK_OBJECT(clist), "select_row",
                            GTK_SIGNAL_FUNC(select_row), NULL);
 	gtk_signal_connect(GTK_OBJECT(clist), "unselect_row",
 			   GTK_SIGNAL_FUNC(select_row), NULL);
-#if GY_NEW
-/*	gtk_signal_connect_after(GTK_OBJECT(clist), "select_row",
-                           GTK_SIGNAL_FUNC(select_row2), NULL); */
-#endif
-	return clist;
+	return GTK_WIDGET(clist);
 }
 
 static inline void
@@ -365,3 +234,10 @@ void setup_clist(GtkWidget *clist)
         gtk_clist_thaw(GTK_CLIST(clist));
 
 }	
+
+/* Arrgh - lets all use the same tabs under emacs: 
+Local Variables:
+tab-width: 8
+c-basic-offset: 8
+indent-tabs-mode: nil
+*/   
